@@ -78,13 +78,13 @@ impl<'de> Deserialize<'de> for PermissionOverwrite {
 
         let kind = match data.kind {
             PermissionOverwriteTargetType::Member => {
-                let id = UserId(data.id);
+                let id = UserId::new(data.id).expect("non zero");
                 tracing::trace!(id = %id.0, kind = ?data.kind);
 
                 PermissionOverwriteType::Member(id)
             }
             PermissionOverwriteTargetType::Role => {
-                let id = RoleId(data.id);
+                let id = RoleId::new(data.id).expect("non zero");
                 tracing::trace!(id = %id.0, kind = ?data.kind);
 
                 PermissionOverwriteType::Role(id)
@@ -173,7 +173,7 @@ mod tests {
         let overwrite = PermissionOverwrite {
             allow: Permissions::CREATE_INVITE,
             deny: Permissions::KICK_MEMBERS,
-            kind: PermissionOverwriteType::Member(UserId(12_345_678)),
+            kind: PermissionOverwriteType::Member(UserId::new(12_345_678).expect("non zero")),
         };
 
         // We can't use serde_test because it doesn't support 128 bit integers.
@@ -199,14 +199,14 @@ mod tests {
         let raw = r#"{
   "allow": "1",
   "deny": "2",
-  "id": 0,
+  "id": 1,
   "type": 1
 }"#;
 
         let value = PermissionOverwrite {
             allow: Permissions::CREATE_INVITE,
             deny: Permissions::KICK_MEMBERS,
-            kind: PermissionOverwriteType::Member(UserId(0)),
+            kind: PermissionOverwriteType::Member(UserId::new(1).expect("non zero")),
         };
 
         let deserialized = serde_json::from_str::<PermissionOverwrite>(raw).unwrap();
@@ -225,7 +225,7 @@ mod tests {
                 Token::Str("deny"),
                 Token::Str("2"),
                 Token::Str("id"),
-                Token::Str("0"),
+                Token::Str("1"),
                 Token::Str("type"),
                 Token::U8(1),
                 Token::StructEnd,
