@@ -183,9 +183,10 @@ mod tests {
             },
             guild_id: Some(GuildId::new(1).expect("non zero")),
             member: Some(Member {
+                avatar: None,
                 deaf: false,
                 guild_id: GuildId::new(1).expect("non zero"),
-                joined_at: Some(joined_at),
+                joined_at,
                 mute: false,
                 nick: Some("typing".to_owned()),
                 pending: false,
@@ -247,7 +248,6 @@ mod tests {
                 Token::NewtypeStruct { name: "GuildId" },
                 Token::Str("1"),
                 Token::Str("joined_at"),
-                Token::Some,
                 Token::Str("2020-01-01T00:00:00.000000+00:00"),
                 Token::Str("mute"),
                 Token::Bool(false),
