@@ -311,9 +311,10 @@ mod tests {
             guild_id: GuildId::new(1).expect("non zero"),
             members: Vec::from([
                 Member {
+                    avatar: None,
                     deaf: false,
                     guild_id: GuildId::new(1).expect("non zero"),
-                    joined_at: Some(joined_at),
+                    joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: false,
@@ -341,9 +342,10 @@ mod tests {
                     },
                 },
                 Member {
+                    avatar: None,
                     deaf: false,
                     guild_id: GuildId::new(1).expect("non zero"),
-                    joined_at: Some(joined_at),
+                    joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: false,
@@ -368,9 +370,10 @@ mod tests {
                     },
                 },
                 Member {
+                    avatar: None,
                     deaf: false,
                     guild_id: GuildId::new(1).expect("non zero"),
-                    joined_at: Some(joined_at),
+                    joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: true,
@@ -391,13 +394,14 @@ mod tests {
                         flags: None,
                         premium_type: None,
                         system: None,
-                        public_flags: Some(UserFlags::VERIFIED_BOT_DEVELOPER),
+                        public_flags: Some(UserFlags::VERIFIED_DEVELOPER),
                     },
                 },
                 Member {
+                    avatar: None,
                     deaf: false,
                     guild_id: GuildId::new(1).expect("non zero"),
-                    joined_at: Some(joined_at),
+                    joined_at,
                     mute: false,
                     nick: Some("chunk".to_owned()),
                     pending: false,
