@@ -41,7 +41,8 @@ pub use self::{
 use self::member::MemberListDeserializer;
 use super::gateway::presence::PresenceListDeserializer;
 use crate::{
-    channel::{GuildChannel, StageInstance},
+    channel::{message::sticker::Sticker, GuildChannel, StageInstance},
+    datetime::Timestamp,
     gateway::presence::Presence,
     id::{ApplicationId, ChannelId, GuildId, UserId},
     voice::voice_state::VoiceState,
@@ -73,7 +74,7 @@ pub struct Guild {
     pub icon: Option<String>,
     pub id: GuildId,
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub joined_at: Option<String>,
+    pub joined_at: Option<Timestamp>,
     pub large: bool,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub max_members: Option<u64>,
@@ -105,6 +106,8 @@ pub struct Guild {
     pub splash: Option<String>,
     #[serde(skip_serializing_if = "Vec::is_empty")]
     pub stage_instances: Vec<StageInstance>,
+    #[serde(skip_serializing_if = "Vec::is_empty")]
+    pub stickers: Vec<Sticker>,
     pub system_channel_flags: SystemChannelFlags,
     pub system_channel_id: Option<ChannelId>,
     #[serde(default)]
@@ -162,6 +165,7 @@ impl<'de> Deserialize<'de> for Guild {
             Roles,
             Splash,
             StageInstances,
+            Stickers,
             SystemChannelFlags,
             SystemChannelId,
             RulesChannelId,
@@ -220,6 +224,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let mut roles = None;
                 let mut splash = None::<Option<_>>;
                 let mut stage_instances = None::<Vec<StageInstance>>;
+                let mut stickers = None::<Vec<Sticker>>;
                 let mut system_channel_id = None::<Option<_>>;
                 let mut system_channel_flags = None;
                 let mut threads = None::<Vec<GuildChannel>>;
@@ -410,7 +415,8 @@ impl<'de> Deserialize<'de> for Guild {
                                 return Err(DeError::duplicate_field("members"));
                             }
 
-                            let deserializer = MemberListDeserializer::new(GuildId(0));
+                            let deserializer =
+                                MemberListDeserializer::new(GuildId::new(1).expect("non zero"));
 
                             members = Some(map.next_value_seed(deserializer)?);
                         }
@@ -482,7 +488,8 @@ impl<'de> Deserialize<'de> for Guild {
                                 return Err(DeError::duplicate_field("presences"));
                             }
 
-                            let deserializer = PresenceListDeserializer::new(GuildId(0));
+                            let deserializer =
+                                PresenceListDeserializer::new(GuildId::new(1).expect("non zero"));
 
                             presences = Some(map.next_value_seed(deserializer)?);
                         }
@@ -507,6 +514,13 @@ impl<'de> Deserialize<'de> for Guild {
 
                             stage_instances = Some(map.next_value()?);
                         }
+                        Field::Stickers => {
+                            if stickers.is_some() {
+                                return Err(DeError::duplicate_field("stickers"));
+                            }
+
+                            stickers = Some(map.next_value()?);
+                        }
                         Field::SystemChannelId => {
                             if system_channel_id.is_some() {
                                 return Err(DeError::duplicate_field("system_channel_id"));
@@ -625,6 +639,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let rules_channel_id = rules_channel_id.unwrap_or_default();
                 let splash = splash.unwrap_or_default();
                 let stage_instances = stage_instances.unwrap_or_default();
+                let stickers = stickers.unwrap_or_default();
                 let system_channel_id = system_channel_id.unwrap_or_default();
                 let mut threads = threads.unwrap_or_default();
                 let unavailable = unavailable.unwrap_or_default();
@@ -673,6 +688,7 @@ impl<'de> Deserialize<'de> for Guild {
                     ?roles,
                     ?splash,
                     ?stage_instances,
+                    ?stickers,
                     ?system_channel_flags,
                     ?system_channel_id,
                     ?threads,
@@ -775,6 +791,7 @@ impl<'de> Deserialize<'de> for Guild {
                     rules_channel_id,
                     splash,
                     stage_instances,
+                    stickers,
                     system_channel_flags,
                     system_channel_id,
                     threads,
@@ -841,20 +858,25 @@ impl<'de> Deserialize<'de> for Guild {
 
 #[cfg(test)]
 mod tests {
+
     use super::{
         ApplicationId, ChannelId, DefaultMessageNotificationLevel, ExplicitContentFilter, Guild,
         GuildId, MfaLevel, NSFWLevel, Permissions, PremiumTier, SystemChannelFlags, UserId,
         VerificationLevel,
     };
+    use crate::datetime::{Timestamp, TimestampParseError};
     use serde_test::Token;
+    use std::str::FromStr;
 
     #[allow(clippy::too_many_lines)]
     #[test]
-    fn test_guild() {
+    fn test_guild() -> Result<(), TimestampParseError> {
+        let joined_at = Timestamp::from_str("2015-04-26T06:26:56.936000+00:00")?;
+
         let value = Guild {
-            afk_channel_id: Some(ChannelId(2)),
+            afk_channel_id: Some(ChannelId::new(2).expect("non zero")),
             afk_timeout: 900,
-            application_id: Some(ApplicationId(3)),
+            application_id: Some(ApplicationId::new(3).expect("non zero")),
             approximate_member_count: Some(1_200),
             approximate_presence_count: Some(900),
             banner: Some("banner hash".to_owned()),
@@ -866,8 +888,8 @@ mod tests {
             explicit_content_filter: ExplicitContentFilter::MembersWithoutRole,
             features: vec!["a feature".to_owned()],
             icon: Some("icon hash".to_owned()),
-            id: GuildId(1),
-            joined_at: Some("timestamp".to_owned()),
+            id: GuildId::new(1).expect("non zero"),
+            joined_at: Some(joined_at),
             large: true,
             max_members: Some(25_000),
             max_presences: Some(10_000),
@@ -877,7 +899,7 @@ mod tests {
             mfa_level: MfaLevel::Elevated,
             name: "the name".to_owned(),
             nsfw_level: NSFWLevel::Default,
-            owner_id: UserId(5),
+            owner_id: UserId::new(5).expect("non zero"),
             owner: Some(false),
             permissions: Some(Permissions::SEND_MESSAGES),
             preferred_locale: "en-us".to_owned(),
@@ -885,17 +907,18 @@ mod tests {
             premium_tier: PremiumTier::Tier1,
             presences: Vec::new(),
             roles: Vec::new(),
-            rules_channel_id: Some(ChannelId(6)),
+            rules_channel_id: Some(ChannelId::new(6).expect("non zero")),
             splash: Some("splash hash".to_owned()),
             stage_instances: Vec::new(),
+            stickers: Vec::new(),
             system_channel_flags: SystemChannelFlags::SUPPRESS_PREMIUM_SUBSCRIPTIONS,
-            system_channel_id: Some(ChannelId(7)),
+            system_channel_id: Some(ChannelId::new(7).expect("non zero")),
             threads: Vec::new(),
             unavailable: false,
             vanity_url_code: Some("twilight".to_owned()),
             verification_level: VerificationLevel::Medium,
             voice_states: Vec::new(),
-            widget_channel_id: Some(ChannelId(8)),
+            widget_channel_id: Some(ChannelId::new(8).expect("non zero")),
             widget_enabled: Some(true),
         };
 
@@ -955,7 +978,7 @@ mod tests {
                 Token::Str("1"),
                 Token::Str("joined_at"),
                 Token::Some,
-                Token::Str("timestamp"),
+                Token::Str("2015-04-26T06:26:56.936000+00:00"),
                 Token::Str("large"),
                 Token::Bool(true),
                 Token::Str("max_members"),
@@ -1037,5 +1060,7 @@ mod tests {
                 Token::StructEnd,
             ],
         );
+
+        Ok(())
     }
 }
